@@ -4,7 +4,7 @@ static char yyrcsid[]
 #if __GNUC__ == 2
   __attribute__ ((unused))
 #endif /* __GNUC__ == 2 */
-  = "$OpenBSD: skeleton.c,v 1.16 2001/02/26 00:03:33 tholo Exp $";
+  = "$OpenBSD: skeleton.c,v 1.19 2002/12/03 21:34:21 mickey Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -16,7 +16,7 @@ static char yyrcsid[]
 #define yyerrok (yyerrflag=0)
 #define YYRECOVERING() (yyerrflag!=0)
 #define YYPREFIX "yy"
-#line 46 "../../amd/conf_parse.y"
+#line 45 "../../amd/conf_parse.y"
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif /* HAVE_CONFIG_H */
@@ -29,10 +29,14 @@ static char yyrcsid[]
 #  include <alloca.h>
 # else /* not HAVE_ALLOCA_H */
 #  ifdef _AIX
-#pragma alloca
+/*
+ * This pragma directive is indented so that pre-ANSI C compilers will
+ * ignore it, rather than choke on it.
+ */
+ #pragma alloca
 #  else /* not _AIX */
 #   ifndef alloca
-  /* predefined by HP cc +Olibcalls */
+/* predefined by HP cc +Olibcalls */
 voidp alloca();
 #   endif /* not alloca */
 #  endif /* not _AIX */
@@ -40,7 +44,7 @@ voidp alloca();
 #endif /* not __GNUC__ */
 
 extern char *yytext;
-extern int yylineno;
+extern int ayylineno;
 extern int yylex(void);
 
 static int yyerror(const char *s);
@@ -52,18 +56,18 @@ static char *header_section = NULL; /* start with no header section */
 #define PARSE_DEBUG 0
 
 #if PARSE_DEBUG
-# define dprintf(f,s) fprintf(stderr, (f), yylineno, (s))
+# define dprintf(f,s) fprintf(stderr, (f), ayylineno, (s))
 # define amu_return(v)
-#else
+#else /* not PARSE_DEBUG */
 # define dprintf(f,s)
 # define amu_return(v) return((v))
-#endif /* PARSE_DEBUG */
+#endif /* not PARSE_DEBUG */
 
-#line 90 "../../amd/conf_parse.y"
+#line 93 "../../amd/conf_parse.y"
 typedef union {
 char *strtype;
 } YYSTYPE;
-#line 67 "y.tab.c"
+#line 71 "conf_parse.c"
 #define LEFT_BRACKET 257
 #define RIGHT_BRACKET 258
 #define EQUAL 259
@@ -72,37 +76,75 @@ char *strtype;
 #define NONWSEQ_STRING 262
 #define QUOTED_NONWSEQ_STRING 263
 #define YYERRCODE 256
-short yylhs[] = {                                        -1,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yylhs[] =
+#else
+short yylhs[] =
+#endif
+	{                                        -1,
     2,    0,    4,    0,    1,    1,    3,    3,    5,    6,
     7,    7,    8,    8,    8,    8,
 };
-short yylen[] = {                                         2,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yylen[] =
+#else
+short yylen[] =
+#endif
+	{                                         2,
     0,    3,    0,    2,    1,    2,    1,    2,    2,    4,
     1,    2,    4,    4,    4,    1,
 };
-short yydefred[] = {                                      0,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yydefred[] =
+#else
+short yydefred[] =
+#endif
+	{                                      0,
     0,    0,    0,    0,    0,    0,    4,    0,    0,    6,
     2,    0,    8,   16,    0,    9,    0,    0,    0,   12,
    10,    0,    0,    0,   13,   14,   15,
 };
-short yydgoto[] = {                                       1,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yydgoto[] =
+#else
+short yydgoto[] =
+#endif
+	{                                       1,
     5,    2,    7,    3,    8,    9,   16,   17,
 };
-short yysindex[] = {                                      0,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yysindex[] =
+#else
+short yysindex[] =
+#endif
+	{                                      0,
     0, -256, -246, -256, -246, -249,    0, -246, -251,    0,
     0, -245,    0,    0, -244,    0, -251, -243, -255,    0,
-    0, -242, -241, -240,    0,    0,    0,
-};
-short yyrindex[] = {                                   -257,
+    0, -242, -241, -240,    0,    0,    0,};
+#if defined(__cplusplus) || defined(__STDC__)
+const short yyrindex[] =
+#else
+short yyrindex[] =
+#endif
+	{                                   -257,
     0,    0,    0, -236,    0,    0,    0,   14,    0,    0,
     0,    0,    0,    0,    0,    0,    1,    0,    0,    0,
-    0,    0,    0,    0,    0,    0,    0,
-};
-short yygindex[] = {                                      0,
+    0,    0,    0,    0,    0,    0,    0,};
+#if defined(__cplusplus) || defined(__STDC__)
+const short yygindex[] =
+#else
+short yygindex[] =
+#endif
+	{                                      0,
    12,    0,   -3,    0,    0,    0,    5,    0,
 };
 #define YYTABLESIZE 258
-short yytable[] = {                                       3,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yytable[] =
+#else
+short yytable[] =
+#endif
+	{                                       3,
    11,   11,    1,    4,   13,   22,   23,   24,   14,   15,
     6,   12,   18,    7,   19,   10,   21,   25,   26,   27,
     5,   20,    0,    0,    0,    0,    0,    0,    0,    0,
@@ -130,7 +172,12 @@ short yytable[] = {                                       3,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,    0,    0,   11,
 };
-short yycheck[] = {                                     257,
+#if defined(__cplusplus) || defined(__STDC__)
+const short yycheck[] =
+#else
+short yycheck[] =
+#endif
+	{                                     257,
     0,    5,  260,  260,    8,  261,  262,  263,  260,  261,
   257,  261,  258,    0,  259,    4,  260,  260,  260,  260,
   257,   17,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
@@ -164,7 +211,7 @@ short yycheck[] = {                                     257,
 #endif
 #define YYMAXTOKEN 263
 #if YYDEBUG
-#if defined(__cplusplus) || __STDC__
+#if defined(__cplusplus) || defined(__STDC__)
 const char * const yyname[] =
 #else
 char *yyname[] =
@@ -179,7 +226,7 @@ char *yyname[] =
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"LEFT_BRACKET","RIGHT_BRACKET",
 "EQUAL","NEWLINE","NONWS_STRING","NONWSEQ_STRING","QUOTED_NONWSEQ_STRING",
 };
-#if defined(__cplusplus) || __STDC__
+#if defined(__cplusplus) || defined(__STDC__)
 const char * const yyrule[] =
 #else
 char *yyrule[] =
@@ -227,20 +274,20 @@ short *yyss;
 short *yysslim;
 YYSTYPE *yyvs;
 int yystacksize;
-#line 166 "../../amd/conf_parse.y"
+#line 169 "../../amd/conf_parse.y"
 
 static int
 yyerror(const char *s)
 {
   fprintf(stderr, "AMDCONF: %s on line %d (section %s)\n",
-	  s, yylineno,
+	  s, ayylineno,
 	  (header_section ? header_section : "null"));
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
 }
-#line 233 "y.tab.c"
+#line 237 "conf_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
-#if defined(__cplusplus) || __STDC__
+#if defined(__cplusplus) || defined(__STDC__)
 static int yygrowstack(void)
 #else
 static int yygrowstack()
@@ -288,19 +335,19 @@ bail:
 #define YYACCEPT goto yyaccept
 #define YYERROR goto yyerrlab
 int
-#if defined(__cplusplus) || __STDC__
+#if defined(__cplusplus) || defined(__STDC__)
 yyparse(void)
 #else
 yyparse()
 #endif
 {
-    register int yym, yyn, yystate;
+    int yym, yyn, yystate;
 #if YYDEBUG
-#if defined(__cplusplus) || __STDC__
-    register const char *yys;
-#else /* !(defined(__cplusplus) || __STDC__) */
-    register char *yys;
-#endif /* !(defined(__cplusplus) || __STDC__) */
+#if defined(__cplusplus) || defined(__STDC__)
+    const char *yys;
+#else /* !(defined(__cplusplus) || defined(__STDC__)) */
+    char *yys;
+#endif /* !(defined(__cplusplus) || defined(__STDC__)) */
 
     if ((yys = getenv("YYDEBUG")))
     {
@@ -432,15 +479,15 @@ yyreduce:
     switch (yyn)
     {
 case 1:
-#line 104 "../../amd/conf_parse.y"
+#line 107 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; }
 break;
 case 3:
-#line 105 "../../amd/conf_parse.y"
+#line 108 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; }
 break;
 case 10:
-#line 120 "../../amd/conf_parse.y"
+#line 123 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr, "sec_header1 = \"%s\"\n", yyvsp[-2].strtype);
@@ -448,7 +495,7 @@ case 10:
 		}
 break;
 case 13:
-#line 132 "../../amd/conf_parse.y"
+#line 135 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -460,7 +507,7 @@ case 13:
 		}
 break;
 case 14:
-#line 142 "../../amd/conf_parse.y"
+#line 145 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -472,7 +519,7 @@ case 14:
 		}
 break;
 case 15:
-#line 152 "../../amd/conf_parse.y"
+#line 155 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -483,7 +530,7 @@ case 15:
 		  }
 		}
 break;
-#line 478 "y.tab.c"
+#line 482 "conf_parse.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
