@@ -1,17 +1,23 @@
 
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_TARNAME "am-utils"
+#define PACKAGE_VERSION "6.1b3-pre"
+#define PACKAGE_STRING "am-utils 6.1b3-pre"
+#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd2.9"
-#define HOST_OS_NAME "openbsd2"
-#define HOST_OS_VERSION "2.9"
+#define HOST_OS "openbsd3.3"
+#define HOST_OS_NAME "openbsd3"
+#define HOST_OS_VERSION "3.3"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-openbsd29.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-openbsd33.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sun Dec  9 21:48:35 EST 2001"
+#define CONFIG_DATE "Sat Aug  2 14:02:59 EDT 2003"
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_VERSION "6.1b3-pre"
+#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1a5-pre"
-#define PACKAGE "am-utils"
-#define VERSION "6.1a5-pre"
+#define VERSION "6.1b3-pre"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -23,7 +29,7 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "2.9"
+#define HOST_HEADER_VERSION "3.3"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -33,6 +39,7 @@
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
+#define GETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -56,6 +63,7 @@
 #define HAVE_MEMSET 1
 #define HAVE_MKDIR 1
 #define HAVE_MKSTEMP 1
+#define HAVE_MLOCKALL 1
 #define HAVE_MOUNT 1
 #define HAVE_REGCOMP 1
 #define HAVE_REGEXEC 1
@@ -63,6 +71,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
 #define HAVE_SETITIMER 1
+#define HAVE_SETRESUID 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -86,6 +95,7 @@
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
+#define HAVE_STRERROR 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -133,7 +143,6 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
@@ -158,6 +167,7 @@
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_LOCK_H 1
 #define HAVE_SYS_MBUF_H 1
+#define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_MOUNT_H 1
 #define HAVE_SYS_PARAM_H 1
 #define HAVE_SYS_PROC_H 1
@@ -175,6 +185,7 @@
 #define HAVE_SYS_UIO_H 1
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_VNODE_H 1
+#define HAVE_UFS_UFS_EXTATTR_H 1
 #define HAVE_UFS_UFS_UFSMOUNT_H 1
 #define HAVE_ASSERT_H 1
 #define HAVE_CTYPE_H 1
@@ -198,6 +209,7 @@
 #define HAVE_STRING_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_SYSLOG_H 1
+#define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
@@ -217,10 +229,6 @@
 #define RECVFROM_FROMLEN_TYPE int
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
-#define cdfs_args_t struct iso_args
-#define mfs_args_t struct mfs_args
-#define pcfs_args_t struct msdosfs_args
-#define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
@@ -251,25 +259,17 @@
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
-#define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
-#define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_PCFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_PCFS_ARGS_T_GID 1
-#define HAVE_FIELD_PCFS_ARGS_T_MASK 1
-#define HAVE_FIELD_PCFS_ARGS_T_UID 1
-#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
-#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
-#define HAVE_FIELD_NFS_ARGS_T_PROTO 1
-#define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
-#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
-#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
-#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
-#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
+#define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_FHSIZE 1
+#define HAVE_NFS_ARGS_T_PROTO 1
+#define HAVE_NFS_ARGS_T_SOTYPE 1
+#define HAVE_NFS_ARGS_T_VERSION 1
+#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
+#define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
-#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -352,3 +352,5 @@
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
+#define HAVE_LIBWRAP 1
+#define NEED_LIBWRAP_SEVERITY_VARIABLES 1
